@@ -50,7 +50,6 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
                                    self.newSudokusSpinButton.get_adjustment()
                                    )
         self.generate_for_target_widgets.append(self.newSudokusSpinButton)
-        self.generate_method_changed_cb()
         self.generateButton = self.glade.get_widget('generateButton')
         self.generateButton.connect('clicked',self.generate_cb)
         self.closeButton = self.glade.get_widget('closeButton')
@@ -62,8 +61,13 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         self.pauseButton.set_sensitive(False)
         self.stopButton.set_sensitive(False)
         self.prog = self.glade.get_widget('progressbar1')
-        self.prog.set_show_text(True)
+        self.prog.set_text('0 %')
         self.working = False
+        self.easyCheckButton.connect('clicked',self.criteria_cb)
+        self.mediumCheckButton.connect('clicked',self.criteria_cb)
+        self.hardCheckButton.connect('clicked',self.criteria_cb)
+        self.veryHardCheckButton.connect('clicked',self.criteria_cb)
+        self.generate_method_changed_cb()
         self.dialog = self.glade.get_widget('PuzzleGenerator')
         self.dialog.show_all()
         self.dialog.present()
@@ -73,9 +77,21 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         if not self.generateForTargetRadio.get_active():
             for w in self.generate_for_target_widgets:
                 w.set_sensitive(False)
+            if not self.working:
+                self.generateButton.set_sensitive(True)
         else:
             for w in self.generate_for_target_widgets:
                 w.set_sensitive(True)
+                self.criteria_cb()
+
+    def criteria_cb (self, *args):
+        if (self.easyCheckButton.get_active()
+            or self.mediumCheckButton.get_active()
+            or self.hardCheckButton.get_active()
+            or self.veryHardCheckButton.get_active()):
+            self.generateButton.set_sensitive(True)
+        else:
+            self.generateButton.set_sensitive(False)
 
     def generate_cb (self, *args):
         self.ngenerated = 0
@@ -83,6 +99,10 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         self.pauseButton.set_sensitive(True)
         self.stopButton.set_sensitive(True)
         self.generateButton.set_sensitive(False)
+        self.generateForTargetRadio.set_sensitive(False)
+        self.generateEndlesslyRadio.set_sensitive(False)
+        for w in self.generate_for_target_widgets:
+            w.set_sensitive(False)
         self.working = True
         self.paused = False
         self.prog.set_text(_('Working...'))
@@ -105,6 +125,11 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         self.pauseButton.set_sensitive(False)
         self.pauseButton.set_active(False)
         self.generateButton.set_sensitive(True)
+        self.generateForTargetRadio.set_sensitive(True)
+        self.generateEndlesslyRadio.set_sensitive(True)
+        if self.generateForTargetRadio.get_active():
+            for w in self.generate_for_target_widgets:
+                w.set_sensitive(True)
         self.working = False
 
     def close_cb (self, widg):
@@ -134,7 +159,7 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         else:
             curval = int(curtext.split()[0])
             newval = curval + val
-        newtext = ngettext("%s puzzle","%s puzzles",newval)%newval
+        newtext = ngettext("%s puzzle","%s puzzles",newval).replace('%s', '%(n)s')%{'n':newval}
         lab.set_text(newtext)
 
     def update_status (self, *args):
@@ -167,12 +192,14 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
                     if (not self.generateForTargetRadio.get_active() or
                         self.veryHardCheckButton.get_active()):
                         self.toward_target += 1
-            self.update_progress_bar()
             if (self.generateForTargetRadio.get_active()
                 and
-                self.newSudokusSpinButton.get_value()==self.toward_target):
+                self.newSudokusSpinButton.get_value()<=self.toward_target):
+                self.toward_target=int(self.newSudokusSpinButton.get_value())
+                self.update_progress_bar()
                 self.stop_cb()
                 return False
+            self.update_progress_bar()
         if self.paused: self.prog.set_text(_('Paused'))
         elif self.generateEndlesslyRadio.get_active():
             self.prog.pulse()
@@ -189,7 +216,7 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
     def update_progress_bar (self):
         if self.generateForTargetRadio.get_active():
             tot = int(self.newSudokusSpinButton.get_value())
-            self.prog.set_percentage(
+            self.prog.set_fraction(
                 float(self.toward_target)/tot
                 )
             try:
@@ -211,7 +238,7 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
                     txt = 'Generated %s out of %s puzzles'%(self.toward_target,tot)
         else:
             self.prog.pulse()
-            txt = ngettext('Generated %s puzzle','Generated %s puzzles')%(self.toward_target)
+            txt = ngettext('Generated %s puzzle','Generated %s puzzles',self.toward_target).replace('%s', '%(n)s')%{'n':self.toward_target}
         if self.paused: txt = txt + ' (' + _('Paused') + ')'
         self.prog.set_text(txt)
 
